courses.Course (Activity) — amici1

# `courses.Course` (Activity)

Course(id, start_date, start_time, end_date, end_time, user, every_unit, every, positions, monday, tuesday, wednesday, thursday, friday, saturday, sunday, max_events, room, max_date, line, teacher, slot, description, remark, state, max_places, name, enrolments_until, description_de, description_fr)

Master tables : courses.ActiveActivities (Current activities), courses.Activities (Activities), courses.ActivitiesByLayout (Activities), courses.AllActivities (Activities), courses.ClosedActivities (Closed courses), courses.DraftActivities (Draft activities), courses.InactiveActivities (Inactive courses), courses.MyActivities (My Activities), courses.MyCoursesGiven (My courses given)

Slave tables : comments.CommentsByMentioned (Mentioned in), comments.RepliesByComment (Replies), courses.ActivitiesByLine (Activities), courses.ActivitiesBySlot (Activities), courses.ActivitiesByTopic (Activities), courses.EnrolmentsByCourse (Enrolments), courses.LinesByTopic (Activity lines)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Start date (start_date) : The start date of the first meeting to be generated.

- Start time (start_time) : See `<lino.core.fields.TimeField: start_time>`.

- End Date (end_date) : The end date of the first meeting to be generated. Leave this field empty if the meetings last less than one day.

- End Time (end_time) : See `<lino.core.fields.TimeField: end_time>`.

- Author (user) : The author of this object. A pointer to lino.modlib.users.models.User.

- Recurrency (every_unit) : The interval between each periodic iteration.

- Repeat every (every) : The frequency of periodic iteration: daily, weekly, monthly or yearly.

- Positions (positions) : Space-separated list of one or several positions within the recurrency cycle.

- Monday (monday) : See `<django.db.models.fields.BooleanField: monday>`.

- Tuesday (tuesday) : See `<django.db.models.fields.BooleanField: tuesday>`.

- Wednesday (wednesday) : See `<django.db.models.fields.BooleanField: wednesday>`.

- Thursday (thursday) : See `<django.db.models.fields.BooleanField: thursday>`.

- Friday (friday) : See `<django.db.models.fields.BooleanField: friday>`.

- Saturday (saturday) : See `<django.db.models.fields.BooleanField: saturday>`.

- Sunday (sunday) : See `<django.db.models.fields.BooleanField: sunday>`.

- Number of events (max_events) : Maximum number of calendar entries to generate.

- Room (room) : See `<django.db.models.fields.related.ForeignKey: room>`.

- Generate events until (max_date) : Don’t generate meeting having their start date beyond this date.

- Activity line (line) : See `<django.db.models.fields.related.ForeignKey: line>`.

- Instructor (teacher) : See `<django.db.models.fields.related.ForeignKey: teacher>`.

- Timetable Slot (slot) : See `<django.db.models.fields.related.ForeignKey: slot>`.

- Description (description) : See `<lino.utils.mldbc.fields.BabelTextField: description>`.

- Remark (remark) : See `<django.db.models.fields.TextField: remark>`.

- State (state) : The workflow state field.

- Available places (max_places) : Available places. The maximum number of participants to allow in this activity.

- Designation (name) : See `<django.db.models.fields.CharField: name>`.

- Enrolments until (enrolments_until) : Until when new enrolments are accepted.

- Description (de) (description_de) : See `<lino.core.fields.RichTextField: description_de>`.

- Description (fr) (description_fr) : See `<lino.core.fields.RichTextField: description_fr>`.

- Print (print_actions) : See `lino_xl.lib.courses.models.Course.print_actions`.

- Calendar entries (events_text) : See `lino_xl.lib.courses.models.Course.events_text`.

- Free places (free_places) : Number of free places.

- Requested (requested) : Number of requested places.

- Confirmed (confirmed) : Number of confirmed places.

- Trying (trying) : Number of trying places.

- Enrolments (enrolments) : See `lino_xl.lib.courses.models.Course.enrolments`.

- Description (what_text) : See `lino_xl.lib.courses.models.Course.what_text`.

- Times (times_text) : See `lino_xl.lib.courses.models.Course.times_text`.

- When (weekdays_text) : A virtual field returning the textual formulation of the weekdays where the recurrence occurs.

- Name (name_column) : See `lino_xl.lib.courses.models.Course.name_column`.

- (None) (navigation_panel) : See `lino_xl.lib.courses.models.Course.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino_xl.lib.courses.models.Course.overview`.

- Duration (duration) : See `lino_xl.lib.courses.models.Course.duration`.

Referenced from courses.Enrolment.course

## Database fields

Internal name | Verbose name | Help text
--- | --- | ---
id | ID |
start_date | Start date | The start date of the first meeting to be generated.
start_time | Start time |
end_date | End Date | The end date of the first meeting to be generated. Leave this field empty if the meetings last less than one day.
end_time | End Time |
user | Author | The author of this object. A pointer to lino.modlib.users.models.User.
every_unit | Recurrency | The interval between each periodic iteration.
every | Repeat every | The frequency of periodic iteration: daily, weekly, monthly or yearly.
positions | Positions | Space-separated list of one or several positions within the recurrency cycle.
monday | Monday |
tuesday | Tuesday |
wednesday | Wednesday |
thursday | Thursday |
friday | Friday |
saturday | Saturday |
sunday | Sunday |
max_events | Number of events | Maximum number of calendar entries to generate.
room | Room |
max_date | Generate events until | Don’t generate meeting having their start date beyond this date.
line | Activity line |
teacher | Instructor |
slot | Timetable Slot |
description | Description |
remark | Remark |
state | State | The workflow state field.
max_places | Available places | Available places. The maximum number of participants to allow in this activity.
name | Designation |
enrolments_until | Enrolments until | Until when new enrolments are accepted.
description_de | Description (de) |
description_fr | Description (fr) |
print_actions | Print |
events_text | Calendar entries |
free_places | Free places | Number of free places.
requested | Requested | Number of requested places.
confirmed | Confirmed | Number of confirmed places.
trying | Trying | Number of trying places.
enrolments | Enrolments |
what_text | Description |
times_text | Times |
weekdays_text | When | A virtual field returning the textual formulation of the weekdays where the recurrence occurs.
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |
duration | Duration |